@@ -2,17 +2,17 @@
 External service key settings
 """
 from askbot.conf.settings_wrapper import settings
-from askbot.deps.livesettings import ConfigurationGroup, StringValue
+from askbot.deps import livesettings
 from django.utils.translation import ugettext as _
 from django.conf import settings as django_settings
 
-EXTERNAL_KEYS = ConfigurationGroup(
+EXTERNAL_KEYS = livesettings.ConfigurationGroup(
                     'EXTERNAL_KEYS',
                     _('Keys to connect the site with external services like Facebook, etc.')
                 )
 
 settings.register(
-    StringValue(
+    livesettings.StringValue(
         EXTERNAL_KEYS,
         'GOOGLE_SITEMAP_CODE',
         description=_('Google site verification key'),
@@ -28,7 +28,7 @@ settings.register(
 )
 
 settings.register(
-    StringValue(
+    livesettings.StringValue(
         EXTERNAL_KEYS,
         'GOOGLE_ANALYTICS_KEY',
         description=_('Google Analytics key'),
@@ -43,7 +43,16 @@ settings.register(
 )
 
 settings.register(
-    StringValue(
+    livesettings.BooleanValue(
+        EXTERNAL_KEYS,
+        'USE_RECAPTCHA',
+        description=_('Enable recaptcha (keys below are required)'),
+        default=False
+    )
+)
+
+settings.register(
+    livesettings.StringValue(
         EXTERNAL_KEYS,
         'RECAPTCHA_KEY',
         description=_('Recaptcha public key')
@@ -51,7 +60,7 @@ settings.register(
 )
 
 settings.register(
-    StringValue(
+    livesettings.StringValue(
         EXTERNAL_KEYS,
         'RECAPTCHA_SECRET',
         description=_('Recaptcha private key'),
@@ -64,9 +73,8 @@ settings.register(
     )
 )
 
-
 settings.register(
-    StringValue(
+    livesettings.StringValue(
         EXTERNAL_KEYS,
         'FACEBOOK_KEY',
         description=_('Facebook public API key'),
@@ -81,7 +89,7 @@ settings.register(
 )
 
 settings.register(
-    StringValue(
+    livesettings.StringValue(
         EXTERNAL_KEYS,
         'FACEBOOK_SECRET',
         description=_('Facebook secret key')
@@ -89,7 +97,7 @@ settings.register(
 )
 
 settings.register(
-    StringValue(
+    livesettings.StringValue(
         EXTERNAL_KEYS,
         'TWITTER_KEY',
         description=_('Twitter consumer key'),
@@ -102,7 +110,7 @@ settings.register(
 )
 
 settings.register(
-    StringValue(
+    livesettings.StringValue(
         EXTERNAL_KEYS,
         'TWITTER_SECRET',
         description=_('Twitter consumer secret'),
@@ -110,7 +118,7 @@ settings.register(
 )
 
 settings.register(
-    StringValue(
+    livesettings.StringValue(
         EXTERNAL_KEYS,
         'LINKEDIN_KEY',
         description=_('LinkedIn consumer key'),
@@ -123,9 +131,42 @@ settings.register(
 )
 
 settings.register(
-    StringValue(
+    livesettings.StringValue(
         EXTERNAL_KEYS,
         'LINKEDIN_SECRET',
         description=_('LinkedIn consumer secret'),
     )
 )
+
+settings.register(
+    livesettings.BooleanValue(
+        EXTERNAL_KEYS,
+        'USE_LDAP_FOR_PASSWORD_LOGIN',
+        description=_('User LDAP authentication for the password login'),
+        defaut=False
+    )
+)
+
+settings.register(
+    livesettings.StringValue(
+        EXTERNAL_KEYS,
+        'LDAP_PROVIDER_NAME',
+        description=_('LDAP service provider name')
+    )
+)
+
+settings.register(
+    livesettings.StringValue(
+        EXTERNAL_KEYS,
+        'LDAP_URL',
+        description=_('URL for the LDAP service')
+    )
+)
+
+settings.register(
+    livesettings.LongStringValue(
+        EXTERNAL_KEYS,
+        'HOW_TO_CHANGE_LDAP_PASSWORD',
+        description=_('Explain how to change LDAP password')
+    )
+)
