@@ -20,8 +20,10 @@ at run time
 
 askbot.deps.livesettings is a module developed for satchmo project
 """
+from django.core.cache import cache
 from askbot.deps.livesettings import SortedDotDict, config_register
 from askbot.deps.livesettings.functions import config_get
+from askbot.deps.livesettings import signals
 
 class ConfigSettings(object):
     """A very simple Singleton wrapper for settings
@@ -74,11 +76,24 @@ class ConfigSettings(object):
             self.__group_map[key] = group_key
 
     def as_dict(self):
-        out = dict()
-        for key in self.__instance.keys():
-            #todo: this is odd that I could not use self.__instance.items() mapping here
-            out[key] = self.__instance[key].value
-        return out
+        settings = cache.get('askbot-livesettings')
+        if settings:
+            return settings
+        else:
+            self.prime_cache()
+            return cache.get('askbot-livesettings')
 
+    @classmethod
+    def prime_cache(cls, **kwargs):
+        """reload all settings into cache as dictionary
+        """
+        out = dict()
+        for key in cls.__instance.keys():
+            #todo: this is odd that I could not use self.__instance.items() mapping here
+            out[key] = cls.__instance[key].value
+        cache.set('askbot-livesettings', out)
+
+
+signals.configuration_value_changed.connect(ConfigSettings.prime_cache)
 #settings instance to be used elsewhere in the project
 settings = ConfigSettings()
