@@ -5,7 +5,7 @@ import datetime
 from django.core.urlresolvers import reverse
 from askbot.search.indexer import create_fulltext_indexes
 from django.db.models import signals as django_signals
-from django.template import loader, Context
+from django.template import Context
 from django.utils.translation import ugettext as _
 from django.utils.translation import ungettext
 from django.contrib.auth.models import User
@@ -35,6 +35,9 @@ from askbot.startup_tests import run_startup_tests
 
 run_startup_tests()
 
+def get_model(model_name):
+    return models.get_model('askbot', model_name)
+
 User.add_to_class(
             'status', 
             models.CharField(
@@ -1180,6 +1183,50 @@ def get_profile_link(self):
 
     return mark_safe(profile_link)
 
+def user_get_karma_summary(self):
+    """returns human readable sentence about
+    status of user's karma"""
+    return _("%(username)s karma is %(reputation)s") % \
+            {'username': self.username, 'reputation': self.reputation}
+
+def user_get_badge_summary(self):
+    """returns human readable sentence about
+    number of badges of different levels earned
+    by the user. It is assumed that user has some badges"""
+    badge_bits = list()
+    if self.gold:
+        bit = ungettext(
+                'one gold badge',
+                '%(count)d gold badges',
+                self.gold
+            ) % {'count': self.gold}
+        badge_bits.append(bit)
+    if self.silver:
+        bit = ungettext(
+                'one silver badge',
+                '%(count)d silver badges',
+                self.gold
+            ) % {'count': self.silver}
+        badge_bits.append(bit)
+    if self.silver:
+        bit = ungettext(
+                'one bronze badge',
+                '%(count)d bronze badges',
+                self.gold
+            ) % {'count': self.bronze}
+        badge_bits.append(bit)
+
+    if len(badge_bits) == 1:
+        badge_str = badge_bits[0]
+    elif len(badge_bits) > 1:
+        last_bit = badge_bits.pop()
+        badge_str = ', '.join(badge_bits)
+        badge_str = _('%(item1)s and %(item2)s') % \
+                    {'item1': badge_str, 'item2': last_bit}
+    else:
+        raise ValueError('user must have badges to call this function')
+    return _("%(user)s has %(badges)s") % {'user': self.username, 'badges':badge_str}
+
 #series of methods for user vote-type commands
 #same call signature func(self, post, timestamp=None, cancel=None)
 #note that none of these have business logic checks internally
@@ -1496,7 +1543,8 @@ def send_instant_notifications_about_activity_in_post(
     if update_activity.activity_type not in acceptable_types:
         return
 
-    template = loader.get_template('instant_notification.html')
+    from askbot.skins.loaders import ENV
+    template = ENV.get_template('instant_notification.html')
 
     update_type_map = const.RESPONSE_ACTIVITY_TYPE_MAP_FOR_TEMPLATES
     update_type = update_type_map[update_activity.activity_type]
@@ -1891,4 +1939,6 @@ __all__ = [
         #'AuthKeyUserAssociation',
 
         'User',
+
+        'get_model'
 ]
