@@ -17,6 +17,8 @@ from askbot.models import content
 from askbot import const
 from askbot.utils.lists import LazyList
 from askbot.utils.slug import slugify
+from askbot.utils import markup
+from askbot.utils.html import sanitize_html
 
 #todo: too bad keys are duplicated see const sort methods
 QUESTION_ORDER_BY_MAP = {
@@ -47,6 +49,7 @@ class QuestionManager(models.Manager):
             #summary field is denormalized in .save() call
         )
         if question.wiki:
+            #DATED COMMENT
             #todo: this is confusing - last_edited_at field
             #is used as an indicator whether question has been edited
             #in template askbot/skins/default/templates/post_contributor_info.html
@@ -67,19 +70,31 @@ class QuestionManager(models.Manager):
         return question
 
     def run_advanced_search(
-                            self,
-                            request_user = None,
-                            scope_selector = const.DEFAULT_POST_SCOPE,#unanswered/all/favorite (for logged in)
-                            search_query = None,
-                            tag_selector = None,
-                            author_selector = None,#???question or answer author or just contributor
-                            sort_method = const.DEFAULT_POST_SORT_METHOD
-                            ):
+                        self,
+                        request_user = None,
+                        search_state = None
+                    ):
         """all parameters are guaranteed to be clean
         however may not relate to database - in that case
         a relvant filter will be silently dropped
         """
 
+        scope_selector = getattr(
+                            search_state,
+                            'scope',
+                            const.DEFAULT_POST_SCOPE
+                        )
+
+        search_query = search_state.query
+        tag_selector = search_state.tags
+        author_selector = search_state.author
+
+        sort_method = getattr(
+                            search_state, 
+                            'sort',
+                            const.DEFAULT_POST_SORT_METHOD
+                        )
+
         qs = self.filter(deleted=False)#todo - add a possibility to see deleted questions
 
         #return metadata
@@ -122,6 +137,7 @@ class QuestionManager(models.Manager):
         #user contributed questions & answers
         if author_selector:
             try:
+                #todo maybe support selection by multiple authors
                 u = User.objects.get(id=int(author_selector))
                 qs = qs.filter(
                             models.Q(author=u, deleted=False) \
@@ -132,46 +148,63 @@ class QuestionManager(models.Manager):
                 meta_data['author_name'] = None
 
         #get users tag filters
+        ignored_tag_names = None
         if request_user and request_user.is_authenticated():
             uid_str = str(request_user.id)
             #mark questions tagged with interesting tags
-            qs = qs.extra(
-                select = SortedDict([
-                    (
-                        'interesting_score', 
-                        'SELECT COUNT(1) FROM askbot_markedtag, question_tags '
-                         + 'WHERE askbot_markedtag.user_id = %s '
-                         + 'AND askbot_markedtag.tag_id = question_tags.tag_id '
-                         + 'AND askbot_markedtag.reason = \'good\' '
-                         + 'AND question_tags.question_id = question.id'
-                    ),
-                        ]),
-                select_params = (uid_str,),
-             )
-            if request_user.hide_ignored_questions:
-                #exclude ignored tags if the user wants to
-                ignored_tags = Tag.objects.filter(user_selections__reason='bad',
-                                                user_selections__user = request_user)
-                qs = qs.exclude(tags__in=ignored_tags)
-            else:
-                #annotate questions tagged with ignored tags
-                qs = qs.extra(
-                            select = SortedDict([
-                                (
-                                    'ignored_score', 
-                                    'SELECT COUNT(1) FROM askbot_markedtag, question_tags '
-                                      + 'WHERE askbot_markedtag.user_id = %s '
-                                      + 'AND askbot_markedtag.tag_id = question_tags.tag_id '
-                                      + 'AND askbot_markedtag.reason = \'bad\' '
-                                      + 'AND question_tags.question_id = question.id'
+            #a kind of fancy annotation, would be nice to avoid it
+            interesting_tags = Tag.objects.filter(
+                                    user_selections__user=request_user,
+                                    user_selections__reason='good'
                                 )
-                                    ]),
-                            select_params = (uid_str, )
-                         )
+            ignored_tags = Tag.objects.filter(
+                                    user_selections__user=request_user,
+                                    user_selections__reason='bad'
+                                )
+
+            meta_data['interesting_tag_names'] = [tag.name for tag in interesting_tags]
+
+            ignored_tag_names = [tag.name for tag in ignored_tags]
+            meta_data['ignored_tag_names'] = ignored_tag_names
+
+            if interesting_tags:
+                #expensive query
+                qs = qs.extra(
+                    select = SortedDict([
+                        (
+                            'interesting_score', 
+                            'SELECT COUNT(1) FROM askbot_markedtag, question_tags '
+                             + 'WHERE askbot_markedtag.user_id = %s '
+                             + 'AND askbot_markedtag.tag_id = question_tags.tag_id '
+                             + 'AND askbot_markedtag.reason = \'good\' '
+                             + 'AND question_tags.question_id = question.id'
+                        ),
+                            ]),
+                    select_params = (uid_str,),
+                 )
             # get the list of interesting and ignored tags (interesting_tag_names, ignored_tag_names) = (None, None)
-            pt = MarkedTag.objects.filter(user=request_user)
-            meta_data['interesting_tag_names'] = pt.filter(reason='good').values_list('tag__name', flat=True)
-            meta_data['ignored_tag_names'] = pt.filter(reason='bad').values_list('tag__name', flat=True)
+
+            if ignored_tags:
+                if request_user.hide_ignored_questions:
+                    #exclude ignored tags if the user wants to
+                    qs = qs.exclude(tags__in=ignored_tags)
+                else:
+                    #annotate questions tagged with ignored tags
+                    #expensive query
+                    qs = qs.extra(
+                        select = SortedDict([
+                            (
+                                'ignored_score', 
+                                'SELECT COUNT(1) '
+                                  + 'FROM askbot_markedtag, question_tags '
+                                  + 'WHERE askbot_markedtag.user_id = %s '
+                                  + 'AND askbot_markedtag.tag_id = question_tags.tag_id '
+                                  + 'AND askbot_markedtag.reason = \'bad\' '
+                                  + 'AND question_tags.question_id = question.id'
+                            )
+                                ]),
+                        select_params = (uid_str, )
+                     )
 
         #qs = qs.select_related(depth=1)
         #todo: fix orderby here
@@ -180,7 +213,22 @@ class QuestionManager(models.Manager):
             #relevance will be ignored here
             qs = qs.order_by(orderby)
         qs = qs.distinct()
-        return qs, meta_data
+        qs = qs.select_related(
+                        'last_activity_by__id',
+                        'last_activity_by__username',
+                        'last_activity_by__reputation',
+                        'last_activity_by__gold',
+                        'last_activity_by__silver',
+                        'last_activity_by__bronze'
+                    )
+
+        related_tags = Tag.objects.get_related_to_search(
+                                        questions = qs,
+                                        search_state = search_state,
+                                        ignored_tag_names = ignored_tag_names
+                                    )
+
+        return qs, meta_data, related_tags
 
     #todo: this function is similar to get_response_receivers
     #profile this function against the other one
@@ -189,7 +237,11 @@ class QuestionManager(models.Manager):
         answer_list = []
         #question_list = list(question_list)#important for MySQL, b/c it does not support
         from askbot.models.answer import Answer
-        q_id = list(question_list.values_list('id', flat=True))
+        if isinstance(question_list, list):
+            q_id = [question.id for question in question_list]
+        else:
+            q_id = list(question_list.values_list('id', flat=True))
+
         a_id = list(Answer.objects.filter(question__in=q_id).values_list('id', flat=True))
         u_id = set(self.filter(id__in=q_id).values_list('author', flat=True))
         u_id = u_id.union(
@@ -306,9 +358,6 @@ class Question(content.Content, DeletableContent):
 
         return LazyList(get_data)
 
-    def get_tag_names(self):
-        return self.tagnames.split(' ')
-
     def get_similarity(self, other_question = None):
         """return number of tags in the other question
         that overlap with the current question (self)
@@ -513,18 +562,18 @@ class Question(content.Content, DeletableContent):
 
         if initial_addition:
             tags = Tag.objects.get_or_create_multiple(
-                                       self.tagname_list(),
+                                       self.get_tag_names(),
                                        self.author
                                     )
             self.tags.add(*tags)
             Tag.objects.update_use_counts(tags)
 
-    def tagname_list(self):
+    def get_tag_names(self):
         """Creates a list of Tag names from the ``tagnames`` attribute."""
-        return [name for name in self.tagnames.split(u' ')]
+        return self.tagnames.split(u' ')
 
     def tagname_meta_generator(self):
-        return u','.join([unicode(tag) for tag in self.tagname_list()])
+        return u','.join([unicode(tag) for tag in self.get_tag_names()])
 
     def get_absolute_url(self):
         return '%s%s' % (
@@ -652,6 +701,9 @@ class FavoriteQuestion(models.Model):
     def __unicode__(self):
         return '[%s] favorited at %s' %(self.user, self.added_at)
 
+QUESTION_REVISION_TEMPLATE = ('<h3>%(title)s</h3>\n'
+                              '<div class="text">%(html)s</div>\n'
+                              '<div class="tags">%(tags)s</div>')
 class QuestionRevision(ContentRevision):
     """A revision of a Question."""
     question   = models.ForeignKey(Question, related_name='revisions')
@@ -669,6 +721,15 @@ class QuestionRevision(ContentRevision):
         #print 'in QuestionRevision.get_absolute_url()'
         return reverse('question_revisions', args=[self.question.id])
 
+    def as_html(self):
+        markdowner = markup.get_parser()
+        return QUESTION_REVISION_TEMPLATE % {
+            'title': self.title,
+            'html': sanitize_html(markdowner.convert(self.text)),
+            'tags': ' '.join(['<a class="post-tag">%s</a>' % tag
+                              for tag in self.tagnames.split(' ')]),
+        }
+
     def save(self, **kwargs):
         """Looks up the next available revision number."""
         if not self.revision:
