@@ -18,9 +18,10 @@ from django.template.defaulttags import url as default_url
 from django.core.urlresolvers import reverse
 from askbot.skins import utils as skin_utils
 from askbot.utils import colors
-from askbot.utils.functions import get_from_dict_or_object
+from askbot.utils import functions
 from askbot.utils.slug import slugify
 from askbot.templatetags import extra_filters
+from askbot.skins.loaders import ENV
 
 register = template.Library()
 
@@ -42,9 +43,9 @@ def gravatar(user, size):
     appropriate values.
     """
     #todo: rewrite using get_from_dict_or_object
-    gravatar = get_from_dict_or_object(user, 'gravatar')
-    username = get_from_dict_or_object(user, 'username')
-    user_id = get_from_dict_or_object(user, 'id')
+    gravatar = functions.get_from_dict_or_object(user, 'gravatar')
+    username = functions.get_from_dict_or_object(user, 'username')
+    user_id = functions.get_from_dict_or_object(user, 'id')
     slug = slugify(username)
     user_profile_url = reverse('user_profile', kwargs={'id':user_id,'slug':slug})
     #safe_username = template.defaultfilters.urlencode(username)
@@ -74,6 +75,7 @@ def tag_font_size(max_size, min_size, current_size):
     return MIN_FONTSIZE + round((MAX_FONTSIZE - MIN_FONTSIZE) * weight)
 
 
+#todo: this function may need to be removed to simplify the paginator functionality
 LEADING_PAGE_RANGE_DISPLAYED = TRAILING_PAGE_RANGE_DISPLAYED = 5
 LEADING_PAGE_RANGE = TRAILING_PAGE_RANGE = 4
 NUM_PAGES_OUTSIDE_RANGE = 1
@@ -123,18 +125,6 @@ def cnprog_paginator(context):
             "extend_url" : extend_url
         }
 
-@register.inclusion_tag("pagesize.html")
-def cnprog_pagesize(context):
-    """
-    display the pagesize selection boxes for paginator
-    """
-    if (context["is_paginated"]):
-        return {
-            "base_url": context["base_url"],
-            "page_size" : context["page_size"],
-            "is_paginated": context["is_paginated"]
-        }
-
 @register.inclusion_tag("post_contributor_info.html")
 def post_contributor_info(post,contributor_type='original_author'):
     """contributor_type: original_author|last_updater
@@ -266,15 +256,6 @@ def get_user_vote_image(dic, key, arrow):
             return '-on'
     return ''
         
-@register.simple_tag
-def get_age(birthday):
-    current_time = datetime.datetime(*time.localtime()[0:6])
-    year = birthday.year
-    month = birthday.month
-    day = birthday.day
-    diff = current_time - datetime.datetime(year,month,day,0,0,0)
-    return diff.days / 365
-
 @register.simple_tag
 def get_total_count(up_count, down_count):
     return up_count + down_count
@@ -296,36 +277,7 @@ def format_number(value):
         m = re.match(pattern, strValue)
     return first + result
 
-@register.simple_tag
-def convert2tagname_list(question):
-    question['tagnames'] = [name for name in question['tagnames'].split(u' ')]
-    return ''
-
-@register.simple_tag
-def diff_date(date, limen=2, use_on_prefix = False):
-    now = datetime.datetime.now()#datetime(*time.localtime()[0:6])#???
-    diff = now - date
-    days = diff.days
-    hours = int(diff.seconds/3600)
-    minutes = int(diff.seconds/60)
-
-    if days > 2:
-        if date.year == now.year:
-            date_token = date.strftime("%b %d")
-        else:
-            date_token = date.strftime("%b %d '%y")
-        if use_on_prefix:
-            return _('on %(date)s') % { 'date': date_token }
-        else:
-            return date_token
-    elif days == 2:
-        return _('2 days ago')
-    elif days == 1:
-        return _('yesterday')
-    elif minutes >= 60:
-        return ungettext('%(hr)d hour ago','%(hr)d hours ago',hours) % {'hr':hours}
-    else:
-        return ungettext('%(min)d min ago','%(min)d mins ago',minutes) % {'min':minutes}
+diff_date = register.simple_tag(functions.diff_date)
 
 @register.simple_tag
 def get_latest_changed_timestamp():
@@ -418,6 +370,33 @@ def joinitems(parser,token):
 
     return JoinItemListNode(separator=sep_node,last_separator=last_sep_node,items=nodelist)
 
+class IncludeJinja(template.Node):
+    """http://www.mellowmorning.com/2010/08/24/"""
+    def __init__(self, filename):
+        self.filename = filename
+    def render(self, context):
+        jinja_template = ENV.get_template(self.filename)
+        return jinja_template.render(context)
+
+@register.tag
+def include_jinja(parser, token):
+    bits = token.contents.split()
+
+    #Check if a filename was given
+    if len(bits) != 2:
+        error_message = '%r tag requires the name of the ' + \
+                        'template to be included included'
+        raise template.TemplateSyntaxError(error_message % bits[0])
+    filename = bits[1]
+
+    #Remove quotes or raise error
+    if filename[0] in ('"', "'") and filename[-1] == filename[0]:
+        filename = filename[1:-1]
+    else:
+        raise template.TemplateSyntaxError('file name must be quoted')
+
+    return IncludeJinja(filename)
+
 class BlockMediaUrlNode(template.Node):
     def __init__(self,nodelist):
         self.items = nodelist 
@@ -467,65 +446,6 @@ def fullmedia(url):
     path = media(url)
     return "%s%s" % (domain, path)
 
-@register.inclusion_tag('question_counter_widget.html') #too slow
-def question_counter_widget(question):
-    """returns colorized counter widget for a question
-
-    .. versionchanged:: 0.6.6
-        switched from inclusion tag style to in-code template string
-        for the better speed of the front page rendering
-    """
-    view_count = get_from_dict_or_object(question, 'view_count')
-    answer_count = get_from_dict_or_object(question, 'answer_count')
-    vote_count = get_from_dict_or_object(question, 'score')
-    answer_accepted = get_from_dict_or_object(question, 'answer_accepted')
-
-    #background and foreground colors for each item
-    (views_fg, views_bg) = colors.get_counter_colors(
-                view_count,
-                counter_max = askbot_settings.VIEW_COUNTER_EXPECTED_MAXIMUM,
-                zero_bg = askbot_settings.COLORS_VIEW_COUNTER_EMPTY_BG,
-                zero_fg = askbot_settings.COLORS_VIEW_COUNTER_EMPTY_FG,
-                min_bg = askbot_settings.COLORS_VIEW_COUNTER_MIN_BG,
-                min_fg = askbot_settings.COLORS_VIEW_COUNTER_MIN_FG,
-                max_bg = askbot_settings.COLORS_VIEW_COUNTER_MAX_BG,
-                max_fg = askbot_settings.COLORS_VIEW_COUNTER_MAX_FG,
-            )
-    #views_fg = askbot_settings.COLORS_VIEW_COUNTER_EMPTY_FG
-    #views_bg = askbot_settings.COLORS_VIEW_COUNTER_EMPTY_BG
-
-    (answers_fg, answers_bg) = colors.get_counter_colors(
-                answer_count,
-                counter_max = askbot_settings.ANSWER_COUNTER_EXPECTED_MAXIMUM,
-                zero_bg = askbot_settings.COLORS_ANSWER_COUNTER_EMPTY_BG,
-                zero_fg = askbot_settings.COLORS_ANSWER_COUNTER_EMPTY_FG,
-                min_bg = askbot_settings.COLORS_ANSWER_COUNTER_MIN_BG,
-                min_fg = askbot_settings.COLORS_ANSWER_COUNTER_MIN_FG,
-                max_bg = askbot_settings.COLORS_ANSWER_COUNTER_MAX_BG,
-                max_fg = askbot_settings.COLORS_ANSWER_COUNTER_MAX_FG,
-            )
-    #answers_fg = askbot_settings.COLORS_ANSWER_COUNTER_EMPTY_FG
-    #answers_bg = askbot_settings.COLORS_ANSWER_COUNTER_EMPTY_BG
-    if answer_accepted:
-        #todo: maybe recalculate the foreground color too
-        answers_bg = askbot_settings.COLORS_ANSWER_COUNTER_ACCEPTED_BG
-        answers_fg = askbot_settings.COLORS_ANSWER_COUNTER_ACCEPTED_FG
-
-    (votes_fg, votes_bg) = colors.get_counter_colors(
-                vote_count,
-                counter_max = askbot_settings.VOTE_COUNTER_EXPECTED_MAXIMUM,
-                zero_bg = askbot_settings.COLORS_VOTE_COUNTER_EMPTY_BG,
-                zero_fg = askbot_settings.COLORS_VOTE_COUNTER_EMPTY_FG,
-                min_bg = askbot_settings.COLORS_VOTE_COUNTER_MIN_BG,
-                min_fg = askbot_settings.COLORS_VOTE_COUNTER_MIN_FG,
-                max_bg = askbot_settings.COLORS_VOTE_COUNTER_MAX_BG,
-                max_fg = askbot_settings.COLORS_VOTE_COUNTER_MAX_FG,
-            )
-    votes_fg = askbot_settings.COLORS_VOTE_COUNTER_EMPTY_FG
-    votes_fg = askbot_settings.COLORS_VOTE_COUNTER_EMPTY_BG
-
-    return locals()
-
 class IsManyNode(template.Node):
     def __init__(self, test_items, true_nodelist, false_nodelist):
         self.true_nodelist = true_nodelist
