@@ -14,12 +14,11 @@ from django.shortcuts import render_to_response, get_object_or_404
 from django.http import HttpResponseRedirect, HttpResponse, HttpResponseForbidden, Http404
 from django.core.paginator import Paginator, EmptyPage, InvalidPage
 from django.template import RequestContext, Context
-from django.template import loader
 from django.template import defaultfilters
 from django.utils.html import *
 from django.utils import simplejson
-from django.db.models import Q
 from django.utils.translation import ugettext as _
+from django.utils import translation
 from django.core.urlresolvers import reverse
 from django.views.decorators.cache import cache_page
 from django.core import exceptions as django_exceptions
@@ -40,6 +39,7 @@ from askbot.search.state_manager import SearchState
 from askbot.templatetags import extra_tags
 from askbot.templatetags import extra_filters
 from askbot.conf import settings as askbot_settings
+from askbot.skins.loaders import ENV #jinja2 template loading enviroment
 
 # used in index page
 #todo: - take these out of const or settings
@@ -103,9 +103,9 @@ def questions(request):
     #todo: form is used only for validation...
     if form.is_valid():
         search_state.update_from_user_input(
-                                                form.cleaned_data, 
-                                                request.GET, 
-                                            )
+                                    form.cleaned_data,
+                                    request.GET,
+                                )
         #todo: better put these in separately then analyze
         #what neesd to be done, otherwise there are two routines
         #that take request.GET I don't like this use of parameters
@@ -119,42 +119,36 @@ def questions(request):
     #search_state.reset()
     #request.session.modified = True
 
-    #have this call implemented for sphinx, mysql and pgsql
-    (qs, meta_data) = Question.objects.run_advanced_search(
-                            request_user = request.user,
-                            scope_selector = search_state.scope,#unanswered/all/favorite (for logged in)
-                            search_query = search_state.query,
-                            tag_selector = search_state.tags,
-                            author_selector = search_state.author,
-                            sort_method = search_state.sort
-                        )
+    #todo: have this call implemented for sphinx, mysql and pgsql
+    (qs, meta_data, related_tags) = Question.objects.run_advanced_search(
+                                            request_user = request.user,
+                                            search_state = search_state,
+                                        )
 
-    objects_list = Paginator(qs, search_state.page_size)
+    paginator = Paginator(qs, search_state.page_size)
 
-    if objects_list.num_pages < search_state.page:
+    if paginator.num_pages < search_state.page:
         raise Http404
 
-    questions = objects_list.page(search_state.page)
+    page = paginator.page(search_state.page)
 
-    #todo maybe do this search on query the set instead
-    related_tags = Tag.objects.get_tags_by_questions(questions.object_list)
-    contributors = Question.objects.get_question_and_answer_contributors(questions.object_list)
+    contributors = Question.objects.get_question_and_answer_contributors(page.object_list)
 
     paginator_context = {
-        'is_paginated' : True,
-        'pages': objects_list.num_pages,
+        'is_paginated' : (paginator.count > search_state.page_size),
+        'pages': paginator.num_pages,
         'page': search_state.page,
-        'has_previous': questions.has_previous(),
-        'has_next': questions.has_next(),
-        'previous': questions.previous_page_number(),
-        'next': questions.next_page_number(),
-        'base_url' : request.path + '?sort=%s&' % search_state.sort,#todo in T sort=>sort_method
+        'has_previous': page.has_previous(),
+        'has_next': page.has_next(),
+        'previous': page.previous_page_number(),
+        'next': page.next_page_number(),
+        'base_url' : request.path + '?sort=%s&amp;' % search_state.sort,#todo in T sort=>sort_method
         'page_size' : search_state.page_size,#todo in T pagesize -> page_size
     }
 
     if request.is_ajax():
 
-        q_count = objects_list.count
+        q_count = paginator.count
         question_counter = ungettext(
                                 '%(q_num)s question',
                                 '%(q_num)s questions',
@@ -163,14 +157,13 @@ def questions(request):
                                 'q_num': humanize.intcomma(q_count),
                             }
 
-        paginator_tpl = loader.get_template('paginator.html')
-        paginator_html = paginator_tpl.render(
-                                    Context(
-                                        extra_tags.cnprog_paginator(
-                                                        paginator_context
-                                                    )
-                                    )
-                                )
+        paginator_tpl = ENV.get_template('paginator.html')
+        #todo: remove this patch on context after all templates are moved to jinja
+        paginator_context['base_url'] = request.path + '?sort=%s&' % search_state.sort
+        data = {
+            'paginator_context': extra_tags.cnprog_paginator(paginator_context)
+        }
+        paginator_html = paginator_tpl.render(Context(data))
         ajax_data = {
             #current page is 1 by default now
             #because ajax is only called by update in the search button
@@ -199,7 +192,7 @@ def questions(request):
         for tag in related_tags:
             tag_data = {
                 'name': tag.name,
-                'used_count': humanize.intcomma(tag.used_count)
+                'used_count': humanize.intcomma(tag.local_used_count)
             }
             ajax_data['related_tags'].append(tag_data)
 
@@ -221,7 +214,7 @@ def questions(request):
         views_color_min_fg = askbot_settings.COLORS_VIEW_COUNTER_MIN_FG
         views_bgcolor_min = askbot_settings.COLORS_VIEW_COUNTER_MIN_BG
 
-        for question in questions.object_list:
+        for question in page.object_list:
             timestamp = question.last_activity_at
             author = question.last_activity_by
 
@@ -302,15 +295,24 @@ def questions(request):
 
     tags_autocomplete = _get_tags_cache_json()
 
+    reset_method_count = 0
+    if search_state.query:
+        reset_method_count += 1
+    if search_state.tags:
+        reset_method_count += 1
+    if meta_data.get('author_name',None):
+        reset_method_count += 1
 
     template_context = RequestContext(request, {
+        'language_code': translation.get_language(),
+        'reset_method_count': reset_method_count,
         'view_name': 'questions',
         'active_tab': 'questions',
-        'questions' : questions,
+        'questions' : page,
         'contributors' : contributors,
         'author_name' : meta_data.get('author_name',None),
         'tab_id' : search_state.sort,
-        'questions_count' : objects_list.count,
+        'questions_count' : paginator.count,
         'tags' : related_tags,
         'query': search_state.query,
         'search_tags' : search_state.tags,
@@ -323,18 +325,15 @@ def questions(request):
         'context' : paginator_context,
         })
 
-    #todo: organize variables by type
-    if request.is_ajax():
-        template = loader.get_template('questions_ajax.html')
-        question_snippet = template.render(template_context)
-        output = {'question_snippet': question_snippet}
-        #print simplejson.dumps(output)
-        return HttpResponse(simplejson.dumps(output), mimetype='application/json')
-    else:
-        template = loader.get_template('questions.html')
-        return HttpResponse(template.render(template_context))
+    assert(request.is_ajax() == False)
+    #ajax request is handled in a separate branch above
+
+    #before = datetime.datetime.now()
+    template = ENV.get_template('questions.html')
+    response = HttpResponse(template.render(template_context))
     #after = datetime.datetime.now()
-    #print 'time to render %s' % (after - before)
+    #print after - before
+    return response
 
 def search(request): #generates listing of questions matching a search query - including tags and just words
     """redirects to people and tag search pages
@@ -382,24 +381,29 @@ def tags(request):#view showing a listing of available tags - plain list
     except (EmptyPage, InvalidPage):
         tags = objects_list.page(objects_list.num_pages)
 
-    return render_to_response('tags.html', {
-                                            "view_name":"tags",
-                                            "active_tab": "tags",
-                                            "tags" : tags,
-                                            "stag" : stag,
-                                            "tab_id" : sortby,
-                                            "keywords" : stag,
-                                            "context" : {
-                                                'is_paginated' : is_paginated,
-                                                'pages': objects_list.num_pages,
-                                                'page': page,
-                                                'has_previous': tags.has_previous(),
-                                                'has_next': tags.has_next(),
-                                                'previous': tags.previous_page_number(),
-                                                'next': tags.next_page_number(),
-                                                'base_url' : reverse('tags') + '?sort=%s&' % sortby
-                                            }
-                                }, context_instance=RequestContext(request))
+    paginator_data = {
+        'is_paginated' : is_paginated,
+        'pages': objects_list.num_pages,
+        'page': page,
+        'has_previous': tags.has_previous(),
+        'has_next': tags.has_next(),
+        'previous': tags.previous_page_number(),
+        'next': tags.next_page_number(),
+        'base_url' : reverse('tags') + '?sort=%s&amp;' % sortby
+    }
+    paginator_context = extra_tags.cnprog_paginator(paginator_data)
+    data = {
+        'view_name':'tags',
+        'active_tab': 'tags',
+        'tags' : tags,
+        'stag' : stag,
+        'tab_id' : sortby,
+        'keywords' : stag,
+        'paginator_context' : paginator_context
+    }
+    context = RequestContext(request, data)
+    template = ENV.get_template('tags.html')
+    return HttpResponse(template.render(context))
 
 def question(request, id):#refactor - long subroutine. display question body, answers and comments
     """view that displays body of the question and 
@@ -514,7 +518,20 @@ def question(request, id):#refactor - long subroutine. display question body, an
             #get response notifications
             request.user.visit_question(question)
 
-    return render_to_response('question.html', {
+    paginator_data = {
+        'is_paginated' : (objects_list.count > ANSWERS_PAGE_SIZE),
+        'pages': objects_list.num_pages,
+        'page': page,
+        'has_previous': page_objects.has_previous(),
+        'has_next': page_objects.has_next(),
+        'previous': page_objects.previous_page_number(),
+        'next': page_objects.next_page_number(),
+        'base_url' : request.path + '?sort=%s&amp;' % view_id,
+        'extend_url' : "#sort-top"
+    }
+    paginator_context = extra_tags.cnprog_paginator(paginator_data)
+
+    data = {
         'view_name': 'question',
         'active_tab': 'questions',
         'question' : question,
@@ -527,70 +544,31 @@ def question(request, id):#refactor - long subroutine. display question body, an
         'tab_id' : view_id,
         'favorited' : favorited,
         'similar_questions' : question.get_similar_questions(),
-        'context' : {
-            'is_paginated' : True,
-            'pages': objects_list.num_pages,
-            'page': page,
-            'has_previous': page_objects.has_previous(),
-            'has_next': page_objects.has_next(),
-            'previous': page_objects.previous_page_number(),
-            'next': page_objects.next_page_number(),
-            'base_url' : request.path + '?sort=%s&' % view_id,
-            'extend_url' : "#sort-top"
-        }
-        }, context_instance=RequestContext(request))
+        'language_code': translation.get_language(),
+        'paginator_context' : paginator_context
+    }
+    context = RequestContext(request, data)
+    template = ENV.get_template('question.html')
+    return HttpResponse(template.render(context))
 
-QUESTION_REVISION_TEMPLATE = ('<h1>%(title)s</h1>\n'
-                              '<div class="text">%(html)s</div>\n'
-                              '<div class="tags">%(tags)s</div>')
-def question_revisions(request, id):
-    post = get_object_or_404(Question, id=id)
+def revisions(request, id, object_name=None):
+    assert(object_name in ('Question', 'Answer'))
+    post = get_object_or_404(get_model(object_name), id=id)
     revisions = list(post.revisions.all())
     revisions.reverse()
-    markdowner = markup.get_parser()
     for i, revision in enumerate(revisions):
-        revision.html = QUESTION_REVISION_TEMPLATE % {
-            'title': revision.title,
-            'html': sanitize_html(markdowner.convert(revision.text)),
-            'tags': ' '.join(['<a class="post-tag">%s</a>' % tag
-                              for tag in revision.tagnames.split(' ')]),
-        }
-        if i > 0:
-            revisions[i].diff = htmldiff(revisions[i-1].html, revision.html)
+        revision.html = revision.as_html()
+        if i == 0:
+            revision.diff = revisions[i].html
+            revision.summary = _('initial version')
         else:
-            revisions[i].diff = QUESTION_REVISION_TEMPLATE % {
-                'title': revisions[0].title,
-                'html': sanitize_html(markdowner.convert(revisions[0].text)),
-                'tags': ' '.join(['<a class="post-tag">%s</a>' % tag
-                                 for tag in revisions[0].tagnames.split(' ')]),
-            }
-            revisions[i].summary = _('initial version') 
-    return render_to_response('revisions_question.html', {
-                              'view_name':'question_revisions',
-                              'active_tab':'questions',
-                              'post': post,
-                              'revisions': revisions,
-                              }, context_instance=RequestContext(request))
-
-ANSWER_REVISION_TEMPLATE = ('<div class="text">%(html)s</div>')
-def answer_revisions(request, id):
-    post = get_object_or_404(Answer, id=id)
-    revisions = list(post.revisions.all())
-    revisions.reverse()
-    markdowner = markup.get_parser()
-    for i, revision in enumerate(revisions):
-        revision.html = ANSWER_REVISION_TEMPLATE % {
-            'html': sanitize_html(markdowner.convert(revision.text))
-        }
-        if i > 0:
-            revisions[i].diff = htmldiff(revisions[i-1].html, revision.html)
-        else:
-            revisions[i].diff = revisions[i].text
-            revisions[i].summary = _('initial version')
-    return render_to_response('revisions_answer.html', {
-                              'view_name':'answer_revisions',
-                              'active_tab':'questions',
-                              'post': post,
-                              'revisions': revisions,
-                              }, context_instance=RequestContext(request))
-
+            revision.diff = htmldiff(revisions[i-1].html, revision.html)
+    data = {
+        'view_name':'answer_revisions',
+        'active_tab':'questions',
+        'post': post,
+        'revisions': revisions,
+    }
+    context = RequestContext(request, data)
+    template = ENV.get_template('revisions.html')
+    return HttpResponse(template.render(context))
